@@ -1,5 +1,5 @@
 package WWW::AzimuthAero;
-$WWW::AzimuthAero::VERSION = '0.31';
+$WWW::AzimuthAero::VERSION = '0.4';
 
 # ABSTRACT: Parser for https://azimuth.aero/
 
@@ -25,13 +25,12 @@ use Data::Dumper::AutoEncode;
 sub new {
     my ( $self, %params ) = @_;
     $params{ua_obj} = Mojo::UserAgent->new() unless defined $params{ua_obj};
-    $params{ua_str} =
-'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.109 Safari/537.36'
-      unless defined $params{ua_str};
+    $params{ua_str} = 'TAIS' unless defined $params{ua_str};
     $params{ua_obj}->transactor->name( $params{ua_str} );
 
     # get cookies, otheerwise will be 403 error
-    my $req = $params{ua_obj}->get('https://booking.azimuth.aero/');
+    my $req = $params{ua_obj}->get('https://booking.azimuth.aero/')
+      ;    # Mojo::Transaction::HTTP
 
     # get route map
     my $route_map = $req->res->dom->find('script')
@@ -39,19 +38,24 @@ sub new {
     $route_map = extract_js_glob_var( $route_map, 'data.routes' );
 
     bless {
-        ua        => $params{ua_obj},
-        route_map => WWW::AzimuthAero::RouteMap->new($route_map)
+        ua               => $params{ua_obj},
+        route_map        => WWW::AzimuthAero::RouteMap->new($route_map),
+        last_transaction => $req
     }, $self;
 }
 
 
+sub last_transaction {
+    return shift->{last_transaction};
+}
+
+
 sub get {
     my ( $self, %params ) = @_;
 
     confess "from is not defined" unless defined $params{from};
     confess "to is not defined"   unless defined $params{to};
     confess "date is not defined" unless defined $params{date};
-    confess "date is not defined" unless defined $params{date};
 
     $params{adults} = 1 unless defined $params{adults};
     confess "adults > 9"
@@ -63,7 +67,10 @@ sub get {
       . $params{to} . '/'
       . $params{date} . '/'
       . $params{adults} . '-0-0/';
-    my $req        = $self->{ua}->get($url);
+    my $req = $self->{ua}->get($url);    # Mojo::Transaction::HTTP
+
+    $self->{last_transaction} = $req;
+
     my $target_dom = $req->res->dom->at('div.sf-day__content');
 
     if ( ref($target_dom) eq 'Mojo::DOM' ) {
@@ -130,9 +137,14 @@ sub get {
     }
 
     # return die
-    else {
+    elsif ( $req->res->is_success ) {
+        return { error => 'TAIS fare search error' }
+          if ( $req->res->body =~ /travelshop-support\@tais.ru/ );
         return { error => 'No flights found' };
     }
+    else {
+        return { error => $req->res->code };
+    }
 }
 
 
@@ -146,14 +158,18 @@ sub route_map {
 sub get_schedule_dates {
     my ( $self, %params ) = @_;
 
-    confess "from is not defined" unless defined $params{from};
-    confess "to is not defined"   unless defined $params{to};
+    confess "from city is not defined" unless defined $params{from};
+    confess "to city is not defined"   unless defined $params{to};
 
     my $url =
         'https://azimuth.aero/ru/flights?from='
       . $params{from} . '&to='
       . $params{to};
-    my $res = $self->{ua}->get($url)->res->json;
+
+    my $get_req = $self->{ua}->get($url);
+    $self->{last_transaction} = $get_req;
+
+    my $res = $get_req->res->json;
 
     if ( ref( $res->{available_to} ) eq 'ARRAY' ) {
 
@@ -179,6 +195,8 @@ sub get_schedule_dates {
           . ", url : $url, most likely is transit route"
           if $params{v};
 
+        return () if $params{only_direct_flights};
+
         return get_dates_from_range( min => $params{min}, max => $params{max} )
           ;    # to-do : check max_date
     }
@@ -353,7 +371,7 @@ WWW::AzimuthAero - Parser for https://azimuth.aero/
 
 =head1 VERSION
 
-version 0.31
+version 0.4
 
 =head1 SYNOPSIS
 
@@ -363,6 +381,10 @@ version 0.31
     $az->get_schedule_dates( from => 'ROV', to => 'KLF' );
     
     $az->get( from => 'ROV', to => 'LED', date => '14.06.2019' );
+  
+    # to debug
+    # $az->last_transaction->req->url->to_abs
+    # $az->last_transaction->res->code
     
     $az->get_lowest_fares( from => 'ROV', to => 'LED', max => '14.08.2019' );
     
@@ -423,6 +445,14 @@ L<https://booking.azimuth.aero/!/ROV/LED/19.06.2019/1-0-0/> (for fetching prices
     my $az = Azimuth->new();
     # or my $az = Azimuth->new(ua_str => 'yandex-travel');
 
+=head2 last_transaction
+
+Return last L<Mojo::Transaction::HTTP> object. Very useful for debug if any problems
+
+  $az->last_transaction->req->url->to_abs
+  $az->last_transaction->res->code
+  $az->last_transaction->res->body
+
 =head2 get
 
 Checks for flight between two cities on selected date. 
@@ -463,12 +493,25 @@ Get schedule by requested direction
 
 Return list of available dates in C<'%d.%m.%Y'> format
 
-Always return dates from today
+ALWAYS return dates from today
 
 Method is useful for minimize amount of API requests
 
-If no available_to property set (like at L<https://azimuth.aero/ru/flights?from=ROV&to=PKV> ) 
-will check for 2 months forward and return all dates in range
+=head3 params
+
+B<from> - IATA departure city code
+
+B<to> -IATA arrival city code
+
+B<min> - min date to check in C<'%d.%m.%Y'> format. Today if not specified
+
+B<max> - max date to check in C<'%d.%m.%Y'> format. If not specified explicitly with count from C<available_to> property in API response, otherwise two month ahead
+
+If no C<available_to> property in API response 
+(like at L<https://azimuth.aero/ru/flights?from=ROV&to=PKV> and seems like all indirect flights) 
+and no I<only_direct_flights> param set method will return dates 2 months ahead
+
+B<only_direct_flights> - consider only direct flights (with  C<available_to> property in API response, like at L<https://azimuth.aero/ru/flights?from=ROV&to=LED> )
 
 =head1 HELPER METHODS
 
